==> haskell-css-text-0.1.3.0-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-7hLPk1lUW5YLJ9v2UqMczm
key: css-text-0.1.3.0-7hLPk1lUW5YLJ9v2UqMczm
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
abi: 01a16d3ff81720eda37368c8a535bae2
exposed: True
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
import-dirs: /usr/lib/ghc-8.4.3/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-7hLPk1lUW5YLJ9v2UqMczm
depends:
    attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ base-4.11.1.0
    text-1.2.3.0
abi-depends: attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ=b6c55238d5ca948928baa2c3b9c37177
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-E1tL3lNpEGHJa3BoGLjzPu
key: css-text-0.1.3.0-E1tL3lNpEGHJa3BoGLjzPu
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
abi: 0527c06117a74d1d0f39404f217d9486
exposed: True
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
import-dirs: /usr/lib/ghc-8.4.3/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-E1tL3lNpEGHJa3BoGLjzPu
depends:
    attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk base-4.11.1.0
    text-1.2.3.0
abi-depends: attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk=825d47e693044b92530553d85386444f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
